diff -ubr lcdproc-0.5.1/server/drivers/hd44780-drivers.h lcdproc-0.5.1-dervish/server/drivers/hd44780-drivers.h
--- lcdproc-0.5.1/server/drivers/hd44780-drivers.h	2006-10-06 17:02:47.000000000 +1000
+++ lcdproc-0.5.1-dervish/server/drivers/hd44780-drivers.h	2007-11-17 14:22:13.000000000 +1000
@@ -43,6 +43,7 @@
 	{"lcdserializer", hd_init_serial, "\tnone\n"},
 	{"los-panel", hd_init_serial, "\tnone\n"},
 	{"vdr-lcd", hd_init_serial, "\tnone\n"},
+	{"dervish", hd_init_serial, "\tnone\n"},
 	/* End serial connectiontypes */
 	{"lis2", hd_init_lis2, "\tnone\n"},
 #ifdef HAVE_LIBUSB
diff -ubr lcdproc-0.5.1/server/drivers/hd44780-serial.c lcdproc-0.5.1-dervish/server/drivers/hd44780-serial.c
--- lcdproc-0.5.1/server/drivers/hd44780-serial.c	2006-10-05 01:18:27.000000000 +1000
+++ lcdproc-0.5.1-dervish/server/drivers/hd44780-serial.c	2007-12-09 17:35:25.000000000 +1000
@@ -243,7 +243,13 @@
 
 	if (flags == RS_DATA) {
 		/* Do we need a DATA indicator byte? */
-		if( SERIAL_IF.data_escape!=0 && ch<SERIAL_IF.data_escape_max ) {
+		if(SERIAL_IF.data_escape!=0 /* we do, if we have such a feature */
+		   && 
+		   ((SERIAL_IF.data_escape_max!=0 && ch<SERIAL_IF.data_escape_max) /* and if we escape by ranges */
+		    || (SERIAL_IF.keypad_escape!=0 && SERIAL_IF.keypad_escape==ch) /* or if we output the keypad escape */
+		    || (SERIAL_IF.backlight_escape!=0 && SERIAL_IF.backlight_escape==ch) /* or the backlight escape */
+    		    || SERIAL_IF.instruction_escape==ch)) /* or the instruction escape */
+		{
 			write( p->fd, &SERIAL_IF.data_escape, 1 );
 		}
 		write( p->fd, &ch, 1 );
@@ -257,8 +263,17 @@
 void
 serial_HD44780_backlight (PrivateData *p, unsigned char state)
 {
-	/* TODO */
-	//if (p->have_backlight) ....
+   static unsigned char old_state=0xff;
+
+   if (p->have_backlight && SERIAL_IF.backlight_escape!=0)
+   {
+      if (old_state!=state)
+      {
+	write( p->fd, &SERIAL_IF.backlight_escape,1);
+	write( p->fd, &state, 1 );
+	old_state=state;
+      }
+   }
 }
 
 unsigned char
diff -ubr lcdproc-0.5.1/server/drivers/hd44780-serial.h lcdproc-0.5.1-dervish/server/drivers/hd44780-serial.h
--- lcdproc-0.5.1/server/drivers/hd44780-serial.h	2006-10-05 01:18:27.000000000 +1000
+++ lcdproc-0.5.1-dervish/server/drivers/hd44780-serial.h	2007-12-04 00:22:28.000000000 +1000
@@ -23,11 +23,14 @@
 /* List of connectiontypes managed by this driver, if you change
    something here, remember also to change hd44780-drivers.h */
 static const SerialInterface serial_interfaces[] = {
-	/*    name         instr data     ^ bitrate bits  K   esc  B  esc */
+	/*    name         instr    data     ^ bitrate bits  K  Kesc  B Besc */
 	{"picanlcd",     0x11, 0x12, 0x20,   9600,   8, 0,    0, 0,   0 },
 	{"lcdserializer",  0xFE,    0,    0,   9600,   8, 0,    0, 0,   0 },
 	{"los-panel",      0xFE,    0,    0,   9600,   4, 1, 0xFE, 1,   0 },
-	{"vdr-lcd",        0xFE,    0,    0,   9600,   4, 0,    0, 0,   0 }
+	{"vdr-lcd",        0xFE,    0,    0,   9600,   4,    0,    0, 0,   0 },
+	/* dervish has a data escape but does not require its use,
+	   unless any of its escapes must be sent (0x80..0x83) */
+	{"dervish",        0x80,    0x83, 0,  19200,   4,    0,    0, 1,  0x81 }
 };
 
 /* initialize this particular driver */
